#
# spec file for package crispy-doom
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           crispy-doom
Version:        7.0
Release:        1.1
Summary:        Higher resolution DOOM/Heretic/Hexen/Strife source port
License:        GPL-2.0-or-later
Group:          Amusements/Games/3D/Shoot
URL:            https://github.com/fabiangreffrath/crispy-doom
Source:         https://github.com/fabiangreffrath/crispy-doom/archive/refs/tags/crispy-doom-%version.tar.gz
Patch1:         chdoom-iwaddir.diff
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  fdupes
BuildRequires:  python3-Pillow
BuildRequires:  python3-base
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(SDL2_mixer) >= 2.0.0
BuildRequires:  pkgconfig(SDL2_net) >= 2.0.0
BuildRequires:  pkgconfig(libpng) >= 1.6.10
BuildRequires:  pkgconfig(samplerate)
BuildRequires:  pkgconfig(sdl2) >= 2.0.1
Provides:       crispy-heretic = %version
Provides:       crispy-hexen = %version
Provides:       crispy-strife = %version

%description
Crispy Doom is a limit-removing enhanced-resolution Doom source port
based on Chocolate Doom.

%package bash-completion
Summary:        Crispy Doom command line completion support for bash
Group:          System/Shells
BuildArch:      noarch
Supplements:    (%name and bash-completion)

%description bash-completion
Additions for bash-completion to support crispy-doom.

%prep
%autosetup -p1 -n %name-%name-%version

%build
autoreconf -fi
%configure
%make_build

%install
b="%buildroot"
%make_install iconsdir="%_datadir/icons/hicolor/64x64/apps" \
	docdir="%_docdir/%name"
mkdir -p "$b/%_bindir"
rm -f "$b/%_docdir/%name/INSTALL"
%fdupes %buildroot/%_prefix

%post
echo "INFO: %name: The global IWAD directory is %_datadir/doom."

%files
%_bindir/crispy-*
%_mandir/man*/*
%_datadir/metainfo/
%_datadir/applications/*
%_datadir/icons/*
%_docdir/crispy-*/

%files bash-completion
%_datadir/bash-completion/

%changelog
* Fri Aug  9 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 7.0
  * True color rendering support (from Chocolate Doom 3.1.0 base)
  * Improve display of secret sector coloring in automap when
    custom PLAYPALs are used.
  * Use PWAD-provided color translation tables for colored blood.
  * Allow non-power-of-2 wide sky textures.
  * Add support for Sigil II.
* Sun Jul 16 2023 Dirk Müller <dmueller@suse.com>
- update to 6.0.0:
  * The display settings window in the setup tool has been
    reorganised to a better arrangement.
  * It is now possible to load .lmp files (and play back demos)
    with long filenames
  * In the setup tool, it is now possible to hold down shift when
  * changing key/mouse/joystick bindings to prevent other
    bindings to the same key from being cleared (thanks myk).
  * The joystick menu in the setup tool now has a test button
  * Specifying the -privateserver option implies -server
  * Freedesktop.org desktop files are now installed for Doom and
    the setup tool, which will appear in the main menu on desktop
  * environments such as Gnome and KDE
  * The Chex Quest dehacked patch (chex.deh) will now be detected
    if it is in the same directory as the IWAD file.
  * Added support for the alternate version of the Final Doom
    executable included in some later versions of the Id
    Anthology.
  * Very short sound effects are not played, to better emulate
    the behavior of DMX in Vanilla Doom
  * The null sector dereference emulation code has been imported
    from Prboom+ - this fixes a desync with CLNJ-506.LMP
  * The IDMUS cheat doesn’t work when emulating the v1.9
    executable
  * Menu navigation when using joystick/joypad (thanks AXDOOMER).
  * For configuration file value for shift keys, use scan code
    for right shift, not left shift (thanks AXDOOMER).
  * Default joystick buttons for the setup tool now match Vanilla
  * The default sfx/music volume set by the setup tool is now 8
    instead of 15, matching the game itself. (thanks AXDOOMER).
  * Weapon cycling from the shotgun to the chaingun in Doom 1 now
    works properly (thanks AXDOOMER).
  * MIDI playback that locked up when using an empty MUS / MIDI
    file
  * Default sampling rate used by setup tool changed to 44100Hz,
    to match the game default (thanks AXDOOMER).
* Wed Mar 29 2023 Jan Engelhardt <jengelh@inai.de>
- Switch from packageand() to modern rpm conditionals
- Avoid conflict with chocolate-doom manpages
* Mon Mar 27 2023 Jan Engelhardt <jengelh@inai.de>
- Initial package (version 5.12.0) for build.opensuse.org
